@@ -27,6 +27,7 @@ pub fn functions() -> HashSet<&'static str>
         "determinant",
         "part",
         "norm",
+        "norm_combine",
         "abs",
         "normalize",
         "car",
@@ -320,6 +321,7 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "part(mat,x(,y))",
         "part(vec,x)",
         "norm(num/vec/mat)",
+        "norm_combine(mat)",
         "abs(num/vec/mat)",
         "normalize(vec)",
         "cartesian({r,θ(,φ)})",
