@@ -16,9 +16,13 @@ use crate::{
     AngleType::{Degrees, Gradians, Radians},
     Colors, HowGraphing,
     Notation::{LargeEngineering, Normal, Scientific, SmallEngineering},
-    Number, Options, Variable,
+    Number, Options, Units, Variable,
+};
+use rug::{
+    float::Constant::Pi,
+    ops::{CompleteRound, Pow},
+    Complex, Float, Integer,
 };
-use rug::{float::Constant::Pi, ops::CompleteRound, Complex, Float, Integer};
 use std::cmp::Ordering;
 #[allow(clippy::too_many_arguments)]
 pub fn print_concurrent(
@@ -210,28 +214,6 @@ pub fn print_concurrent(
             let mut out = String::new();
             let split = tempinput.split('#');
             {
-                if split.clone().count() > 6
-                {
-                    print!(
-                        "\x1b[G\n\x1b[Jtoo many graphs\x1b[G\x1b[A\x1b[K{}{}{}",
-                        prompt(options, &colors),
-                        to_output(
-                            &unmodified_input[start..end],
-                            vars,
-                            options.color == crate::Auto::True,
-                            &colors
-                        ),
-                        if options.color == crate::Auto::True
-                        {
-                            "\x1b[0m"
-                        }
-                        else
-                        {
-                            ""
-                        }
-                    );
-                    return (1, HowGraphing::default(), false, false);
-                }
                 if tempinput.contains(';')
                 {
                     let mut options = options;
@@ -430,18 +412,8 @@ pub fn print_concurrent(
             let func = unparsed[..n - 1].to_vec();
             if matches!(
                 func.iter().collect::<String>().as_str(),
-                "re1col"
-                    | "im1col"
-                    | "re2col"
-                    | "im2col"
-                    | "re3col"
-                    | "im3col"
-                    | "re4col"
-                    | "im4col"
-                    | "re5col"
-                    | "im5col"
-                    | "re6col"
-                    | "im6col"
+                "recol"
+                    | "imcol"
                     | "angle"
                     | "notation"
                     | "graph"
@@ -452,12 +424,14 @@ pub fn print_concurrent(
                     | "scic"
                     | "unitsc"
                     | "bracketc"
+                    | "default_units"
                     | "label"
                     | "point"
                     | "points"
                     | "line"
                     | "lines"
                     | "color"
+                    | "colour"
             )
             {
                 print!(
@@ -692,28 +666,6 @@ pub fn print_concurrent(
             {
                 let split = unmodified_input.iter().collect::<String>();
                 let split = split.split('#');
-                if split.clone().count() > 6
-                {
-                    print!(
-                        "\x1b[G\n\x1b[Jtoo many graphs\x1b[G\x1b[A\x1b[K{}{}{}",
-                        prompt(options, &colors),
-                        to_output(
-                            &unmodified_input[start..end],
-                            vars,
-                            options.color == crate::Auto::True,
-                            &colors
-                        ),
-                        if options.color == crate::Auto::True
-                        {
-                            "\x1b[0m"
-                        }
-                        else
-                        {
-                            ""
-                        }
-                    );
-                    return (1, input.2, false, false);
-                }
                 if unmodified_input.contains(&';')
                 {
                     let mut options = options;
@@ -931,6 +883,7 @@ pub fn print_concurrent(
     {
         Num(n) =>
         {
+            let n = custom_units(n, options, &colors);
             let mut output = get_output(options, &colors, &n);
             let (mut frac_a, frac_b) = if options.frac.num
             {
@@ -1190,7 +1143,7 @@ pub fn print_concurrent(
             else
             {
                 print!(
-                    "\x1b[G{}{}\x1b[K{}\x1b[G\n{}{}\x1b[J{}\x1b[G\x1b[A\x1b[{}C{}",
+                    "\x1b[G{}{}\x1b[K{}\x1b[G\n{}{}{}\x1b[J\x1b[G{}{}\x1b[A\x1b[{}C{}",
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
@@ -1208,7 +1161,23 @@ pub fn print_concurrent(
                     },
                     output.0,
                     output.1,
+                    if len1 == width || len2 == width
+                    {
+                        " "
+                    }
+                    else
+                    {
+                        ""
+                    },
                     if frac == 1 { "\x1b[A" } else { "" },
+                    if len1 == width || len2 == width
+                    {
+                        "\x1b[A"
+                    }
+                    else
+                    {
+                        ""
+                    },
                     if options.prompt { 2 } else { 0 } + (end - start),
                     if options.color == crate::Auto::True
                     {
@@ -1258,7 +1227,8 @@ pub fn print_concurrent(
             frac = if options.frac.vec { 1 } else { 0 };
             for (k, i) in v.iter().enumerate()
             {
-                out = get_output(options, &colors, i);
+                let i = custom_units(i.clone(), options, &colors);
+                out = get_output(options, &colors, &i);
                 let i = &i.number;
                 if frac == 1
                 {
@@ -1523,7 +1493,8 @@ pub fn print_concurrent(
                 }
                 for (k, i) in j.iter().enumerate()
                 {
-                    out = get_output(options, &colors, i);
+                    let i = custom_units(i.clone(), options, &colors);
+                    out = get_output(options, &colors, &i);
                     let i = &i.number;
                     if frac == 1
                     {
@@ -1850,6 +1821,7 @@ pub fn print_answer(num: NumStr, options: Options, colors: &Colors)
     {
         Num(n) =>
         {
+            let n = custom_units(n, options, colors);
             let a = get_output(options, colors, &n);
             print!(
                 "{}{}{}{}",
@@ -1899,7 +1871,8 @@ pub fn print_answer(num: NumStr, options: Options, colors: &Colors)
             let mut out;
             for (k, i) in v.iter().enumerate()
             {
-                out = get_output(options, colors, i);
+                let i = custom_units(i.clone(), options, colors);
+                out = get_output(options, colors, &i);
                 output += out.0.as_str();
                 output += out.1.as_str();
                 output += &out.2.unwrap_or_default();
@@ -1971,7 +1944,8 @@ pub fn print_answer(num: NumStr, options: Options, colors: &Colors)
                 }
                 for (k, i) in j.iter().enumerate()
                 {
-                    out = get_output(options, colors, i);
+                    let i = custom_units(i.clone(), options, colors);
+                    out = get_output(options, colors, &i);
                     output += out.0.as_str();
                     output += out.1.as_str();
                     output += &out.2.unwrap_or_default();
@@ -2046,6 +2020,110 @@ pub fn print_answer(num: NumStr, options: Options, colors: &Colors)
         {}
     }
 }
+pub fn custom_units(mut number: Number, options: Options, colors: &Colors) -> Number
+{
+    if !colors.default_units.is_empty()
+    {
+        let mut meter = Complex::with_val(options.prec, 1);
+        let mut second = Complex::with_val(options.prec, 1);
+        let mut kilogram = Complex::with_val(options.prec, 1);
+        let mut ampere = Complex::with_val(options.prec, 1);
+        let mut mole = Complex::with_val(options.prec, 1);
+        let mut candela = Complex::with_val(options.prec, 1);
+        let mut byte = Complex::with_val(options.prec, 1);
+        let mut usd = Complex::with_val(options.prec, 1);
+        let mut unit = Complex::with_val(options.prec, 1);
+        let m = Units {
+            meter: 1.0,
+            ..Units::default()
+        };
+        let s = Units {
+            second: 1.0,
+            ..Units::default()
+        };
+        let kg = Units {
+            kilogram: 1.0,
+            ..Units::default()
+        };
+        let a = Units {
+            ampere: 1.0,
+            ..Units::default()
+        };
+        let mol = Units {
+            mole: 1.0,
+            ..Units::default()
+        };
+        let cd = Units {
+            candela: 1.0,
+            ..Units::default()
+        };
+        let b = Units {
+            byte: 1.0,
+            ..Units::default()
+        };
+        let us = Units {
+            usd: 1.0,
+            ..Units::default()
+        };
+        let un = Units {
+            unit: 1.0,
+            ..Units::default()
+        };
+        for du in &colors.default_units
+        {
+            let u = du.1.units.unwrap_or_default();
+            if u == m
+            {
+                meter = du.1.number.clone()
+            }
+            else if u == s
+            {
+                second = du.1.number.clone()
+            }
+            else if u == kg
+            {
+                kilogram = du.1.number.clone()
+            }
+            else if u == a
+            {
+                ampere = du.1.number.clone()
+            }
+            else if u == mol
+            {
+                mole = du.1.number.clone()
+            }
+            else if u == cd
+            {
+                candela = du.1.number.clone()
+            }
+            else if u == b
+            {
+                byte = du.1.number.clone()
+            }
+            else if u == us
+            {
+                usd = du.1.number.clone()
+            }
+            else if u == un
+            {
+                unit = du.1.number.clone()
+            }
+        }
+        if let Some(u) = number.units
+        {
+            number.number /= meter.pow(u.meter);
+            number.number /= second.pow(u.second);
+            number.number /= kilogram.pow(u.kilogram);
+            number.number /= ampere.pow(u.ampere);
+            number.number /= mole.pow(u.mole);
+            number.number /= candela.pow(u.candela);
+            number.number /= byte.pow(u.byte);
+            number.number /= usd.pow(u.usd);
+            number.number /= unit.pow(u.unit);
+        }
+    }
+    number
+}
 pub fn get_output(
     options: Options,
     colors: &Colors,
@@ -2168,7 +2246,7 @@ pub fn get_output(
                             {
                                 String::new()
                             },
-                            units.to_string(options),
+                            units.to_string(options, colors),
                             if options.color == crate::Auto::True
                             {
                                 "\x1b[0m"
@@ -2288,7 +2366,7 @@ pub fn get_output(
                             {
                                 String::new()
                             },
-                            units.to_string(options),
+                            units.to_string(options, colors),
                             if options.color == crate::Auto::True
                             {
                                 "\x1b[0m"
@@ -2374,7 +2452,7 @@ pub fn get_output(
                 }
                 else
                 {
-                    "i".to_string()
+                    "-i".to_string()
                 }
             }
             else
@@ -2402,7 +2480,7 @@ pub fn get_output(
                         {
                             String::new()
                         },
-                        units.to_string(options),
+                        units.to_string(options, colors),
                         if options.color == crate::Auto::True
                         {
                             "\x1b[0m"
